/*
 * Copyright 2013 Mark Slater
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package net.sourceforge.writexml;

import java.util.ArrayList;

public final class Tag extends WriteableToXml {

    private final Namespace namespace;
    private final TagName name;
    private final Attributes attributes;
    private final Iterable<WriteableToXml> children;

    public Tag(final Namespace namespace, final TagName name, final Attributes attributes, final Iterable<WriteableToXml> children) {
        this.namespace = namespace;
        this.name = name;
        this.attributes = attributes;
        this.children = new ArrayList<WriteableToXml>() {{
            for (final WriteableToXml child : children) {
                add(child);
            }
        }};
    }

    Namespace namespace() {
        return namespace;
    }

    TagName name() {
        return name;
    }

    Attributes attributes() {
        return attributes;
    }

    void writeTo(final XmlWriter xmlWriter) throws XmlWriterException {
        xmlWriter.writeStartTag(this);
        for (final WriteableToXml child : children) {
            child.writeTo(xmlWriter);
        }
        xmlWriter.writeEndTag(this);
    }
}
